// ============================= F28335 BIOS α׷ =========================
//  CPU : TMS320F28335-150M
//     ¥ : 2009-
//      : Ver1.0
//    : www.cpuplaza.com
// Ϸ : CCS3.3
// [ ]  : OSC 30M
// ----------------------------------------------------------------------------
#include "DSP2833x_Device.h"					// Peripheral address definitions
#include "F28335_example.h"					// Main include file

//  
Uint16 AdcBuf[ADC_BUF_LEN];					// ADC data buffer allocation

// ===============================  α׷ ==============================
// [μ] void
// ---------------------------------------------------------------------------
void main(void)
{
	InitSysCtrl();						// Initialize the CPU
	InitPieCtrl();						// Initialize and enable the PIE
	InitWatchdog();						// Initialize the Watchdog Timer
	InitGpio();							// Initialize the shared GPIO pins
	InitXintf();						// Initialize the external memory interface

#ifdef EXAMPLE_FLASH						// EXAMPLE_FLASH, if defined, is in CCS project options
// Copy all Flash sections that need to run from RAM (use memcpy() from RTS library)
// Section secureRamFuncs contains user defined code that runs from CSM secured RAM
	memcpy(	&secureRamFuncs_runstart,&secureRamFuncs_loadstart,&secureRamFuncs_loadend - &secureRamFuncs_loadstart);
// Initialize the Flash and OTP
	InitFlash();						// Initialize the Flash
#endif

	asm(" EALLOW");						// Enable EALLOW protected register access
	GpioCtrlRegs.GPAMUX1.bit.GPIO0  = 1;			// 0=GPIO  1=EPWM1A 2=rsvd 3=rsvd
	
	GpioCtrlRegs.GPBMUX1.bit.GPIO32 = 0;			// GPIO032 GPIO
	GpioCtrlRegs.GPBDIR.bit.GPIO32 = 1;			// GPIO32  output
	GpioDataRegs.GPBSET.bit.GPIO32 = 1;			// GPIO32 pin is set to 1
 	asm(" EDIS");						// Disable EALLOW protected register access

// Peripheral Initialization
	InitAdc();						// Initialize the ADC
	InitEPwm();						// Initialize the PWM

// Enable interrupts
	SetDBGIER(IER | 0x6000);				// Enable everything in IER, plus TINT2 and DLOGINT
	*(volatile unsigned int *)0x00000C14 |= 0x0C00;		// Set TIMER2 FREE=SOFT=1
// main()  ϸ DSP/BIOS ..

}

// ================================ UserInit =================================
// [μ] void
// [] Description: This is the user initialization file to be specified in
//	  the DSP/BIOS configuration file, System - Global Settings.
// ---------------------------------------------------------------------------
void UserInit(void)
{
#ifdef EXAMPLE_FLASH						// EXAMPLE_FLASH, if defined, is in CCS project options

// Section .trcdata is generated by DSP/BIOS.
// It must be copied from its load to its run address BEFORE main().
	memcpy(&trcdata_runstart, &trcdata_loadstart, &trcdata_loadend - &trcdata_loadstart);

#endif
}

// ============================  Ÿ Ÿũ1 =====================
// [μ] void
// --------------------------------------------------------------------
void task1_proc(void)
{
	while(1) {
		TSK_sleep(1);
	}
}

// ============================== PRD0 ٷ =======================
// [μ] void
// [] DSP/BIOS 500ms  Ÿ
// --------------------------------------------------------------------
void Io_Blink(void)
{
static Uint16 gpio_count = 0;					// Used for LOG_printf
	
// Show an example of using LOG_printf() to write to a log buffer
	LOG_printf(&trace, "GPIO_Blink Count = %u", gpio_count++);
	
	GpioDataRegs.GPBTOGGLE.bit.GPIO32 = 1;			// Toggle the pin
}

// ======================= Adc Ʈ ͷƮ ====================
// [μ] void
// [] 50KHz Sample   50EA
// --------------------------------------------------------------------
void AdcSwi(void)
{
static Uint16 *AdcBufPtr = AdcBuf;				// Pointer to buffer

// Manage the ADC registers
	AdcRegs.ADCTRL2.bit.RST_SEQ1 = 1;			// Reset SEQ1 to CONV00 state
	AdcRegs.ADCST.bit.INT_SEQ1_CLR = 1;			// Clear ADC SEQ1 interrupt flag

// Read the ADC result
	*AdcBufPtr++ = AdcRegs.ADCRESULT0 >> 4;			// Read the result
// Brute-force the circular buffer
	if( AdcBufPtr == (AdcBuf + ADC_BUF_LEN) )
		AdcBufPtr = AdcBuf;				// Rewind the pointer to beginning

}
